All things related to parsing FIPS code
Modules
Structs
- AdHoc
Array Expression - Assign
Statement - Statement for assigning a value to an existing binding
- AtIndex
- Array indexing expressions
- Binary
Operation - An operation with two operands
- Block
Expression - Block expressions (i.e. a block of statements terminated with an expression)
- Call
Statement - Statement for calling back to Rust
- Extern
Function Decl - Function
Call - Call of a named function
- Interaction
- Interaction between particle types
- Interaction
Quantity - Specific quantity determined by the interaction of two particle types
- LetStatement
- Statement for introducing a new binding
- Once
Block - Block representing a one-time only action
- Particle
- Node for the information of a
particleblock - Particle
Member - Simulation
- Structure representing a simulation
- Simulation
SubBlock - Subblocks in a simulation that contain the actual statements
- Step
Block - Block representing an action that is to be repeated according to a step range
- Step
Range - Range of steps with start <= i < end
- Unit
- Update
Statement - Statement for updating an interaction quantity
Enums
- Atom
- An atomic expression
- Binary
Operator - A binary operand
- Compile
Time Constant - A compile time constant, i.e. a literal, some pre-defined constant (or an expression of such, TODO)
- Expression
- Types of Expressions
- Fips
Type - A type in the FIPS language
- Identifier
- Interaction
Symmetry - Literal
- A literal
- Reduction
Method - Simulation
Block - All possible blocks inside a simulation
- Statement
- All kinds of statements in Rust
- Substitution
Value - Helper to contain possible values for substitution (kind of a reverse of FipsValue: this is used to represent Rust types given for substitution without assuming that they are also valid types in FIPS)